==> orangehrm-2.4.0.1.tar.gz: orangehrm-2.4.0.1/lib/extractor/hrfunct/EXTRACTOR_EmpEducation.php <==
<?php
/*
// OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
// all the essential functionalities required for any enterprise.
// Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com

// OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
// the GNU General Public License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.

// OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
// without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along with this program;
// if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
// Boston, MA  02110-1301, USA
*/

require_once ROOT_PATH . '/lib/models/hrfunct/EmpEducation.php';

class EXTRACTOR_EmpEducation {

	function EXTRACTOR_EmpEducation() {

		$this->empeducation = new EmpEducation();
	}

	function parseData($postArr) {

		$postArr['txtEmpEduStartDate']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpEduStartDate']);
		$postArr['txtEmpEduEndDate']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpEduEndDate']);

		$this->empeducation->setEmpId(trim($postArr['txtEmpID']));
   		$this->empeducation->setEduCode(trim($postArr['cmbEduCode']));
   		$this->empeducation->setEduMajor(trim($postArr['txtEmpEduMajor']));
   		$this->empeducation->setEduYear(trim($postArr['txtEmpEduYear']));
   		$this->empeducation->setEduGPA(trim($postArr['txtEmpEduGPA']));
   		$this->empeducation->setEduStartDate(trim($postArr['txtEmpEduStartDate']));
   		$this->empeducation->setEduEndDate(trim($postArr['txtEmpEduEndDate']));

		return $this->empeducation;
	}


}
?>

==> orangehrm-2.5.0.4.tar.gz: orangehrm-2.5.0.4/lib/extractor/hrfunct/EXTRACTOR_EmpEducation.php <==
<?php
/*
// OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
// all the essential functionalities required for any enterprise.
// Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com

// OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
// the GNU General Public License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.

// OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
// without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along with this program;
// if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
// Boston, MA  02110-1301, USA
*/

require_once ROOT_PATH . '/lib/models/hrfunct/EmpEducation.php';

class EXTRACTOR_EmpEducation {

	public function __construct() {

		$this->empeducation = new EmpEducation();
	}

	public function parseData($postArr) {

		$postArr['txtEmpEduStartDate']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpEduStartDate']);
		$postArr['txtEmpEduEndDate']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpEduEndDate']);

		$this->empeducation->setEmpId(trim($postArr['txtEmpID']));
   		$this->empeducation->setEduCode(trim($postArr['cmbEduCode']));
   		$this->empeducation->setEduMajor(trim($postArr['txtEmpEduMajor']));
   		$this->empeducation->setEduYear(empty($postArr['txtEmpEduYear'])?'null':trim($postArr['txtEmpEduYear']));
   		$this->empeducation->setEduGPA(trim($postArr['txtEmpEduGPA']));
   		$this->empeducation->setEduStartDate(self::_handleEmptyDates($postArr['txtEmpEduStartDate']));
   		$this->empeducation->setEduEndDate(self::_handleEmptyDates($postArr['txtEmpEduEndDate']));

		return $this->empeducation;
	}

	private static function _handleEmptyDates($date) {

		$date = trim($date);

	    if ($date == "" || $date == "YYYY-mm-DD" || $date == "0000-00-00") {
			return 'null';
	    } else {
	        return "'".$date."'";
	    }

	}

}
?>
